@@ -1,14 +1,17 @@
-# $File: //depot/cpan/Module-Install/lib/Module/Install/Admin.pm $ $Author: autrijus $
-# $Revision: #38 $ $Change: 1396 $ $DateTime: 2003/03/23 21:44:16 $ vim: expandtab shiftwidth=4
-
 package Module::Install::Admin;
-$VERSION = '0.20';
-@ISA = 'Module::Install';
 
 use strict 'vars';
 use File::Path ();
 use inc::Module::Install ();
 
+use vars qw{$VERSION @ISA};
+BEGIN {
+	$VERSION = '0.66_02';
+	@ISA     = qw{Module::Install};
+}
+
+=pod
+
 =head1 NAME
 
 Module::Install::Admin - Author-side manager for Module::Install
@@ -24,7 +27,7 @@ In a B<Module::Install> extension module:
 
 As an one-liner:
 
-    % perl -MModule::Install::Admin -e'&some_method(@args);'
+    % perl "-MModule::Install::Admin" -e'&some_method(@args);'
 
 The two snippets above are really shorthands for
 
@@ -131,28 +134,36 @@ sub copy {
 
     chomp $to;
 
-    local (*FROM, *TO, $/);
+    local (*FROM, *TO, $_);
     open FROM, "< $from" or die "Can't open $from for input:\n$!";
-    my $content = <FROM>;
+    open TO,   "> $to"   or die "Can't open $to for output:\n$!";
+    print TO "#line 1\n";
+
+    my $content;
+    my $in_pod;
+
+    while (<FROM>) {
+        if (/^=(?:b(?:egin|ack)|head\d|(?:po|en)d|item|(?:ove|fo)r)/) {
+            $in_pod = 1;
+        }
+        elsif (/^=cut\s*\z/ and $in_pod) {
+            $in_pod = 0;
+            print TO "#line $.\n";
+        }
+        elsif (!$in_pod) {
+            print TO $_;
+        }
+    }
+
     close FROM;
-
-    $content =~ s/
-        ^=(?:head\d|pod|begin|item|over|for|back|end)\b.*?
-        ^=cut\b[^\n]*$
-        \n*
-    //smgx;
-
-    open TO, "> $to" or die "Can't open $to for output:\n$!";
-    print TO $content;
     close TO;
 
     print "include $to\n";
 }
 
-sub load {
-    my ($self, $method, $copy) = @_;
-
-    # scan through our target to find
+# scan through our target to find
+sub load_all_extensions {
+    my $self = shift;
     unless ($self->{extensions}) {
         $self->{extensions} = [];
         foreach my $inc (@INC) {
@@ -160,9 +171,14 @@ sub load {
             $self->load_extensions("$inc/$self->{path}", $self->{_top});
         }
     }
+    return @{$self->{extensions}};
+}
+
+sub load {
+    my ($self, $method, $copy) = @_;
 
     my @extobj;
-    foreach my $obj (@{$self->{extensions}}) {
+    foreach my $obj ($self->load_all_extensions) {
         next unless defined &{ref($obj)."::$method"};
         my $is_admin = (ref($obj) =~ /^\Q$self->{name}::$self->{dispatch}::/);
         # Don't ever include admin modules, and vice versa.
@@ -190,7 +206,9 @@ sub copy_package {
     return if -f $file; # prevents infinite recursion
 
     $self->copy($pathname => $file);
-    $self->copy_package($_) for @{"$pkg\::ISA"};
+    foreach my $pkg (@{"$pkg\::ISA"}) {
+        $self->copy_package($pkg);
+    }
 }
 
 sub pick {
@@ -261,17 +279,19 @@ sub DESTROY {}
 
 __END__
 
+=pod
+
 =head1 SEE ALSO
 
 L<Module::Install>
 
 =head1 AUTHORS
 
-Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>
+Audrey Tang E<lt>autrijus@autrijus.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2003 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
+Copyright 2003, 2004 by Audrey Tang E<lt>autrijus@autrijus.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
