@@ -1,22 +1,21 @@
-# $File: //depot/cpan/Module-Install/lib/Module/Install/Admin/Manifest.pm $ $Author: ingy $
-# $Revision: #15 $ $Change: 1393 $ $DateTime: 2003/03/23 09:19:28 $ vim: expandtab shiftwidth=4
-
 package Module::Install::Admin::Manifest;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
-$VERSION = '0.01';
+use Module::Install::Base;
+@ISA = qw(Module::Install::Base);
+
+$VERSION = '0.66_02';
 
 use strict;
 use Cwd;
 use File::Spec;
 
 # XXX I really want this method in Module::Install::Admin::Makefile
-# But you can't call across Admin modules. Autrijus??
+# But you can't call across Admin modules. Audrey??
 sub dist_preop {
-    my $self = shift;
-    $self->check_manifest or 
-    do {
-        my $answer = $self->prompt(<<END);
+    my ($self, $distdir) = @_;
+    return if $self->check_manifest;
+
+    print <<"END_MESSAGE";
 
 It appears that your MANIFEST does not contain the same components that
 are currently in the 'inc' directory. 
@@ -26,10 +25,16 @@ Please try running 'make manifest' and then run 'make dist' again.
 Remember to use the MANIFEST.SKIP file to control things that should not
 end up in your MANIFEST. See 'perldoc ExtUtils::Manifest' for details.
 
-Type 'force' if you *really* want to continue making a distribution.
-END
-        exit(1) unless $answer =~ /^force$/i;
-    };
+END_MESSAGE
+    return if $self->prompt(
+        'Do you *really* want to continue making a distribution?', 'n'
+    ) =~ /^[Yy]/;
+
+    if (-d $distdir) {
+        require File::Path;
+        File::Path::rmtree($distdir);
+    }
+    exit(1);
 }
 
 # XXX Needs a refactoring.
@@ -61,7 +66,6 @@ sub check_manifest {
 
   ADDLOOP:
     for my $pathname (sort $self->_find_files($prefix)) {
-        next unless $pathname =~ /\w+\.pm$/i;
         $pathname = "$relative_path/$pathname" if length($relative_path);
         $pathname =~ s!//+!/!g;
         next unless -f $pathname;
@@ -130,7 +134,7 @@ sub _find_files {
         my @files = ();
         local *DIR;
         opendir(DIR, $file) or die "Can't opendir $file";
-        while (my $new_file = readdir(DIR)) {
+        while (defined(my $new_file = readdir(DIR))) {
             next if $new_file =~ /^(\.|\.\.)$/;
             push @files, $self->_find_files($new_file, $file);
         }
@@ -145,8 +149,9 @@ __END__
 
 =head1 COPYRIGHT
 
-Copyright 2003 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>
-Copyright 2003 by Brian Ingerson E<lt>ingy@cpan.orgE<gt>
+Copyright 2003, 2004 by
+Audrey Tang E<lt>autrijus@autrijus.orgE<gt>,
+Brian Ingerson E<lt>ingy@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
