@@ -1,30 +1,33 @@
-# $File: //depot/cpan/Module-Install/lib/Module/Install/Inline.pm $ $Author: ingy $
-# $Revision: #5 $ $Change: 1377 $ $DateTime: 2003/03/20 15:11:54 $ vim: expandtab shiftwidth=4
-
 package Module::Install::Inline;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
-
-$VERSION = '0.01';
 
 use strict;
+use Module::Install::Base;
+
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+	$VERSION = '0.66_02';
+	$ISCORE  = 1;
+	@ISA     = qw{Module::Install::Base};
+}
 
 sub Inline { $_[0] }
 
 sub write {
     my $self = shift;
-    my $name = $self->name
+    my $name = $self->module_name || $self->name
         or die "Please set name() before calling &Inline->write\n";
+    $name =~ s/-/::/g;
     my $object = (split(/::/, $name))[-1] or return;
     my $version = $self->version
         or die "Please set version() or version_from() before calling &Inline->write\n";
 
-    $version =~ /^\d\.\d\d$/ or die << "END";
+    $version =~ /^\d\.\d\d$/ or die <<"END_MESSAGE";
 Invalid version '$version' for $name.
 Must be of the form '#.##'. (For instance '1.23')
-END
+END_MESSAGE
 
     $self->clean_files('_Inline', "$object.inl");
-    $self->requires(Inline => 0.44); # XXX: check for existing? yagni?
+    $self->build_requires('Inline' => 0.44); # XXX: check for existing? yagni?
 
     my $class = ref($self);
     my $prefix = $self->_top->{prefix};
@@ -34,7 +37,7 @@ END
 .SUFFIXES: .pm .inl
 
 .pm.inl:
-\t\$(PERL) -I$prefix -Mblib -MInline=NOISY,_INSTALL_ -M$name -e1 $version \$(INST_ARCHLIB)
+\t\$(PERL) -I$prefix "-Mblib" "-MInline=NOISY,_INSTALL_" "-M$name" -e1 $version \$(INST_ARCHLIB)
 
 pure_all :: $object.inl
 
