@@ -1,9 +1,31 @@
-# $File: //depot/cpan/Module-Install/lib/inc/Module/Install.pm $ $Author: autrijus $
-# $Revision: #13 $ $Change: 1483 $ $DateTime: 2003/05/08 01:26:46 $ vim: expandtab shiftwidth=4
+package inc::Module::Install;
 
-if (-d 'inc/.author') {
-    require File::Path;
-    File::Path::rmtree('inc');
+# This module ONLY loads if the user has manually install their own
+# installation of Module::Install, and are some form of MI author.
+#
+# It runs from the installed location, and is never bundled
+# along with the other bundled modules.
+#
+# So because the version of this differs from the version that will
+# be bundled almost every time, it doesn't have it's own version and
+# isn't part of the synchronisation-checking.
+
+use strict;
+use vars qw{$VERSION};
+BEGIN {
+	# While this version will be overwritten when Module::Install
+	# loads, it remains so Module::Install itself can detect which
+	# version an author currently has installed.
+	# This allows it to implement any back-compatibility features
+	# it may want or need to.
+	$VERSION = '0.66_02';	
+}
+
+my $author = $^O eq 'VMS' ? './inc/_author' : './inc/.author';
+if ( -d $author ) {
+	$Module::Install::AUTHOR = 1;
+	require File::Path;
+	File::Path::rmtree('inc');
 }
 
 unshift @INC, 'inc';
@@ -13,6 +35,8 @@ require Module::Install;
 
 __END__
 
+=pod
+
 =head1 NAME
 
 inc::Module::Install - Module::Install loader
@@ -41,16 +65,16 @@ F<./inc/> is a normal practice, and there is little chance that a
 CPAN distribution will be called C<Something::inc>, so it's much safer
 to use.
 
-Also, it allows for other helper modules like B<ExtUtils::AutoInstall>
+Also, it allows for other helper modules like B<Module::AutoInstall>
 to reside also in F<inc/>, and to make use of them.
 
 =head1 AUTHORS
 
-Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>
+Audrey Tang E<lt>autrijus@autrijus.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2003 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
+Copyright 2003, 2004 by Audrey Tang E<lt>autrijus@autrijus.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
